<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly 

// Build the settings page
function storelocatorwidget_settings_page() {

  $image    = plugins_url('images/logo.png', __FILE__);
  $styles   = plugins_url('css/storelocatorwidget_styles.css', __FILE__);
  $semantic = plugins_url('css/semantic.css', __FILE__);

  $api             = storelocatorwidget_get_storelocatorwidget_api();
  $mapping_service  = storelocatorwidget_get_mapping_service();
  $google_api_key  = storelocatorwidget_get_google_api();
  $mapbox_api_key  = storelocatorwidget_get_mapbox_api();

  wp_enqueue_style('storlocatorwidget_wp_admin_styles', $styles, '', 1.0);
  wp_enqueue_style('storlocatorwidget_wp_admin_semantic', $semantic, '', 1.0);

?>

<div class="wrap ui segment">

<img src="<?php echo esc_url(plugins_url( 'images/logo.png', __FILE__ ) ) // phpcs:ignore PluginCheck.CodeAnalysis.ImageFunctions.NonEnqueuedImage ?>" width="300">	
	<hr>
<div class="instructions">
  <h3>Step by Step Installation Guide</h3>
  <p><b>Step 1</b> - First you'll need to register for a <a href="https://www.storelocatorwidgets.com/admin/Signup">StoreLocatorWidgets.com</a> account. If you don't have one already, you can sign up for a free 30 day trial account <a href="https://www.storelocatorwidgets.com/admin/Signup">here</a>.</p>
  <p><b>Step 2</b> - Once you've signed up, go to the <a href="https://www.storelocatorwidgets.com/admin/Details">Details</a> page and copy the <b>Store Locator API key</b> at the top into the matching field below.</p>
  <p><b>Step 3</b> - Choose one of our three supported mapping services. You can see how they all look in our comparison <a href="https://www.storelocatorwidgets.com/mapservicecomparison" target="_blank">here</a>.
  	<ul>
  		<li style="list-style: initial; margin-left: 55px;"><b>Google Maps</b> - If you choose Google Maps then you'll also need a free <b>Google Maps API key</b>. Get one <a target="_blank" href="https://www.storelocatorwidgets.com/supportarticle?title=How%20to%20add%20a%20Google%20Maps%20API%20key%20to%20your%20store%20locator">here</a> and add it to the field below.</li>
  		<li style="list-style: initial; margin-left: 55px;"><b>Mapbox</b> - If you choose Mapbox then you'll also need a free <b>Mapbox API key</b>. Get one <a target="_blank" href="https://www.storelocatorwidgets.com/supportarticle?title=How%20to%20add%20a%20MapBox%20API%20key%20to%20your%20store%20locator%20software">here</a> and add it to the field below.</li>
  		<li style="list-style: initial; margin-left: 55px;"><b>ExpressMaps</b> - ExpressMaps doesn't require an API key as we provide this as part of your subscription.</li>
  	</ul>
  </p>
  <p><b>Step 4</b> - Once you have all of your <a href="https://www.storelocatorwidgets.com/admin/Stores">stores set up</a> in your StoreLocatorWidget account, you can insert your new Store Locator into any page by using the <b>[storelocatorwidget]</b> shortcode. Just add this shortcode wherever you want the locator to appear on your web page(s).</p>
  <p>If you run into any issues, need any help installing or uploading your store list then don't worry, we are here to help! Just use the chat function on the <a href="https://www.storelocatorwidgets.com/admin/Stores">StoreLocatorWidgets.com</a> website to get in touch with us.</p>
</div>

	
<?php
	// 	if (isset($_REQUEST['admin_post_nonce_field']) && wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['admin_post_nonce_field'])), 'admin_post_action')) echo '<div class="updated"><p>Settings updated successfully.</p></div>';
	// if (isset($_GET['settings-saved']) && !empty(sanitize_text_field(wp_unslash($_GET['settings-saved'])))) echo '<div class="updated"><p>Settings updated successfully.</p></div>';
	if ( isset( $_GET['nonce'] ) && wp_verify_nonce(sanitize_text_field(wp_unslash($_GET['nonce'])), 'settings-saved-nonce' )) echo '<div class="updated"><p>Settings updated successfully.</p></div>';
	// if ( isset( $_GET[ 'settings-saved' ] )) 
?>

<script>
	jQuery(document).ready(function() {
		jQuery('select#mapping_service').change(function(data) {
			var mappingService = jQuery(this).find("option:selected").val();
			jQuery(".api_keys").hide();
			if (mappingService == "Google Maps") jQuery("#google_api_key_div").show();
			else if (mappingService == "Mapbox") jQuery("#mapbox_api_key_div").show();
		});
	});
</script>

<form method="post" action="admin-post.php">
	<?php wp_nonce_field('admin_post_action', 'admin_post_nonce_field'); ?>
    <input type="hidden" name="action" value="storelocatorwidget_api_keys" />
    <table class="form-table">
        <tr valign="top">
          <th scope="row" style="width: 250px">Store Locator API key</th>
          <td><input id="storelocatorwidget_api_box" type="text" name="storelocatorwidget_api_key" class="ui input" size="40" value="<?php echo esc_html($api) ?>" /></td>
        </tr>

        <tr valign="top">
          <th scope="row" style="width: 250px">Mapping Service</th>
          <td>
          	<select class="form-control" name="mapping_service" id="mapping_service">
				<option value="">Please choose a mapping service</option>
				<option value="Google Maps" <?php echo ((esc_html($mapping_service) == "Google Maps") ? "selected" : "") ?>>Google Maps</option>
				<option value="Mapbox" <?php echo ((esc_html($mapping_service) == "Mapbox") ? "selected" : "") ?>>Mapbox</option>
				<option value="ExpressMaps" <?php echo ((esc_html($mapping_service) == "ExpressMaps") ? "selected" : "") ?>>ExpressMaps</option>
			</select>
          </td>
        </tr>

        <tr valign="top" class="api_keys" id="google_api_key_div" <?php echo ((esc_html($mapping_service) == "Google Maps") ? '' : 'style="display: none;"') ?>>
          <th scope="row">Google Maps API key</th>
          <td><input type="text" name="google_api_key" class="ui input" size="40" value="<?php echo esc_html($google_api_key) ?>" /></td>
        </tr>

        <tr valign="top" class="api_keys" id="mapbox_api_key_div" <?php echo ((esc_html($mapping_service) == "Mapbox") ? '' : 'style="display: none;"') ?>>
          <th scope="row">Mapbox API key</th>
          <td><input type="text" name="mapbox_api_key" class="ui input" size="40" value="<?php echo esc_html($mapbox_api_key) ?>" /></td>
        </tr>

    </table>

    <?php submit_button(); ?>

</form>
</div>

<?php }
