<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly 

// Save the storelocatorwidget API key
function storelocatorwidget_save_storelocatorwidget_api($api){
  global $wpdb;

  $table_id = 1;
  $table_name = esc_sql(storelocatorwidget_get_table_name());
  // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching 
  $wpdb->query($wpdb->prepare("UPDATE %i SET storelocatorwidget_api=%s WHERE id = %d", $table_name, $api, $table_id));
}

// Save the Google API key
function storelocatorwidget_save_google_api($google_api_key){
  global $wpdb;

  $table_id = 1;
  $table_name = storelocatorwidget_get_table_name();
  // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching 
  $wpdb->query($wpdb->prepare("UPDATE %i SET google_api=%s WHERE id = %d", $table_name, $google_api_key, $table_id));
}

// Save the Mapbox API key
function storelocatorwidget_save_mapbox_api($mapbox_api_key){
  global $wpdb;

  $table_id = 1;
  $table_name = storelocatorwidget_get_table_name();

  storelocatorwidget_check_add_column($table_name, "mapbox_api");

  // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching 
  $wpdb->query($wpdb->prepare("UPDATE %i SET mapbox_api=%s WHERE id = %d", $table_name, $mapbox_api_key, $table_id));
}

// Save the Mapping Service
function storelocatorwidget_save_mapping_service($mapping_service){
  global $wpdb;

  $table_id = 1;
  $table_name = storelocatorwidget_get_table_name();

  storelocatorwidget_check_add_column($table_name, "mapping_service");

  // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching 
  $wpdb->query($wpdb->prepare("UPDATE %i SET mapping_service=%s WHERE id = %d", $table_name, $mapping_service, $table_id));
}


// Create column if it is not present (due to columns being added in later versions
function storelocatorwidget_check_add_column($table_name, $column_name) {
	global $wpdb;

	$column_definition = "VARCHAR(255) NOT NULL DEFAULT ''"; // Define column type

	// Check if column exists
	// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching 
	$column_exists = $wpdb->get_results($wpdb->prepare("SHOW COLUMNS FROM %s LIKE %s", $table_name, $column_name));

	// Add column if it does not exist
	// phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared, WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.DirectDatabaseQuery.SchemaChange
	if (empty($column_exists)) $wpdb->query("ALTER TABLE $table_name ADD $column_name $column_definition");
}


// Get the storelocatorwidget api from the db
function storelocatorwidget_get_storelocatorwidget_api(){
  global $wpdb;

  $table_id = 1;
  $table_name = storelocatorwidget_get_table_name();
  // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching 
  $api = $wpdb->get_row( $wpdb->prepare( "SELECT storelocatorwidget_api FROM %i WHERE ID = %d", $table_name, $table_id));
  return $api->storelocatorwidget_api;
}

// Get the google API from the db
function storelocatorwidget_get_mapping_service(){
  global $wpdb;

  $table_id = 1;
  $table_name = storelocatorwidget_get_table_name();
  // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching 
  $gapi = $wpdb->get_row( $wpdb->prepare( "SELECT mapping_service FROM %i WHERE ID = %d", $table_name, $table_id));
  return $gapi->mapping_service;
}

// Get the google API from the db
function storelocatorwidget_get_google_api(){
  global $wpdb;

  $table_id = 1;
  $table_name = storelocatorwidget_get_table_name();
  // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching 
  $gapi = $wpdb->get_row( $wpdb->prepare( "SELECT google_api FROM %i WHERE ID = %d", $table_name, $table_id));
  return $gapi->google_api;
}

// Get the google API from the db
function storelocatorwidget_get_mapbox_api(){
  global $wpdb;

  $table_id = 1;
  $table_name = storelocatorwidget_get_table_name();
  // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching 
  $gapi = $wpdb->get_row( $wpdb->prepare( "SELECT mapbox_api FROM %i WHERE ID = %d", $table_name, $table_id));
  return $gapi->mapbox_api;
}


// Process the form data
function storelocatorwidget_process_storelocatorwidget_keys() {
	if (isset($_POST['admin_post_nonce_field']) && wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['admin_post_nonce_field'])), 'admin_post_action')) {
		// Securely process data as nonce is verified

		// Check for the google api key
		if (isset($_POST['google_api_key'])){
		  storelocatorwidget_save_google_api(sanitize_text_field(wp_unslash($_POST['google_api_key'])));
		}

		// Check for the mapbox api key
		if (isset($_POST['mapbox_api_key'])){
		  storelocatorwidget_save_mapbox_api(sanitize_text_field(wp_unslash($_POST['mapbox_api_key'])));
		}

		// Check for the mapping service setting
		if (isset($_POST['mapping_service'])){
		  storelocatorwidget_save_mapping_service(sanitize_text_field(wp_unslash($_POST['mapping_service'])));
		}

		// Check for the slw api key
		if (isset($_POST['storelocatorwidget_api_key'])){
		  storelocatorwidget_save_storelocatorwidget_api(sanitize_text_field(wp_unslash($_POST['storelocatorwidget_api_key'])));
		}

		// redirect
		$nonce = wp_create_nonce('settings-saved-nonce');
		wp_redirect(admin_url( 'admin.php?page=storelocatorwidgets_slug&settings-saved=true&nonce=' . $nonce));
		exit;
	} else {
		wp_die('Security check failed');
	}
}
