<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly 

/*
Plugin Name: Store Locator Widget
Plugin URI: https://en-au.wordpress.org/plugins/store-locator-widget/
Description: Add a powerful Store Locator to your Wordpress site with a user friendly admin console, lots of features and a variety of layouts.
Version: 2025r3
Author: StoreLocatorWidgets.com
Author URI: https://www.storelocatorwidgets.com/
License: GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: store-locator-widget
*/

// Shortcodes
add_shortcode("storelocatorwidget", "storelocatorwidget_handler");

// Add actions
add_action('admin_menu', 'storelocatorwidget_create_menu');
add_action( 'wp_storelocatorwidget_api', 'storelocatorwidget_get_storelocatorwidget_api' );
add_action( 'wp_google_gapi', 'storelocatorwidget_get_google_api' );
add_action( 'wp_mapbox_gapi', 'storelocatorwidget_get_mapbox_api' );
add_action( 'wp_set_google_gapi', 'storelocatorwidget_save_google_api' );
add_action( 'wp_set_mapbox_gapi', 'storelocatorwidget_save_mapbox_api' );
add_action( 'wp_set_storelocatorwidget_gapi', 'storelocatorwidget_save_storelocatorwidget_api' );

// Process the apps
add_action( 'admin_post_storelocatorwidget_api_keys', 'storelocatorwidget_process_storelocatorwidget_keys' );

// Activation Hook
register_activation_hook( __FILE__, 'storelocatorwidget_install' );

// Install functions
define( 'STORELOCATORWIDGET_DB_VERSION', '1.0' );

// Create the table to hold the API keys
function storelocatorwidget_install () {
   global $wpdb;

   $installed_ver = get_option( "storelocatorwidget_db_version" );
   $table_name = storelocatorwidget_get_table_name();

   // $installed_table_name = $wpdb->get_var($wpdb->prepare("SHOW TABLES LIKE %s", $table_name));

  if( $installed_table_name != $table_name || $installed_ver != STORELOCATORWIDGET_DB_VERSION ) {

    $sql = 'CREATE TABLE ' .$table_name. ' (
      id mediumint(9) NOT NULL AUTO_INCREMENT,
      storelocatorwidget_api VARCHAR(255) DEFAULT "" NOT NULL,
      mapping_service VARCHAR(255) DEFAULT "" NOT NULL,
      google_api VARCHAR(255) DEFAULT "" NOT NULL,
      mapbox_api VARCHAR(255) DEFAULT "" NOT NULL,
      UNIQUE KEY id (id)
    );';

    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
    dbDelta( $sql );

    // create the row to hold the settings
	// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery
	$wpdb->insert( $table_name, array('storelocatorwidget_api' => '', 'google_api' => '', 'mapbox_api' => '', 'mapping_service' => ''), array());

    update_option( "storelocatorwidget_db_version", STORELOCATORWIDGET_DB_VERSION );
  }
}

// Get the table prefix and return the name
function storelocatorwidget_get_table_name(){
  global $wpdb;
  return $wpdb->prefix . "storelocatorwidget";
}
// End of Install functions

// The function that actually handles replacing the short code
function storelocatorwidget_handler($incomingfrompost) {

  $api = storelocatorwidget_get_storelocatorwidget_api();
  $mapping_service = storelocatorwidget_get_mapping_service();
  $google_api_key = storelocatorwidget_get_google_api();
  $mapbox_api_key = storelocatorwidget_get_mapbox_api();
  $script_text = "";

  if ($api == "") $script_text = "<p><b>WARNING:</b> First you need to save your Store Locator Widgets API key on the plugin settings page.";
  else if (($mapping_service == "Mapbox") && !$mapbox_api_key) $script_text = "<p><b>WARNING:</b> As you have chosen Mapbox you need to set the Mapbox API key on the plugin settings page.";
  else if ((!$mapping_service || ($mapping_service == "Google Maps")) && !$google_api_key) $script_text = "<p><b>WARNING:</b> As you have chosen Google Maps you need to set the Google Maps API key on the plugin settings page.";
  else $script_text = '<div id="storelocatorwidget" style="width:100%;"><p>Loading <a href="https://www.storelocatorwidgets.com">Store Locator Software</a>...</p></div>';

  // mapping service script
  if ($mapping_service == "Mapbox") {
  	wp_enqueue_script( 'mapboxscript', '//cdn.storelocatorwidgets.com/widget/mapbox-gl-live.js', '', 1.0, true );
  	wp_enqueue_script( 'mapboxgeocoderscript', '//cdn.storelocatorwidgets.com/widget/mapbox-gl-geocoder.js', '', 1.0, true );
  }
  else if ($mapping_service == "ExpressMaps") wp_enqueue_script( 'storelocatorwidget_expressmaps_js', '//cdn.storelocatorwidgets.com/widget/mapbox-gl.js', '', 1.0, true );
  else wp_enqueue_script( 'googlemapsscript', '//maps.googleapis.com/maps/api/js?key=' . $google_api_key . '&libraries=places', '', 1.0, true );
  
  wp_enqueue_script( 'storelocatorwidget_locator_js', '//cdn.storelocatorwidgets.com/widget/widget.js', '', 1.0, true );
  wp_enqueue_script( 'storelocatorwidget_algolia_js', '//cdn.storelocatorwidgets.com/widget/algolia-autocomplete.js', '', 1.0, true );

  add_filter( 'script_loader_tag', 'storelocatorwidget_script_loader_tag', 10 ,2 );

  $incomingfrompost = shortcode_atts(array("headingstart" => $script_text), esc_html($incomingfrompost));

  $demolph_output = storelocatorwidget_script_output($incomingfrompost);
  return $demolph_output;
}


function storelocatorwidget_script_loader_tag( $tag, $handle ) {
  $api = storelocatorwidget_get_storelocatorwidget_api();
  $mapping_service = storelocatorwidget_get_mapping_service();

  $platformstr = "";
  if ($mapping_service == "Mapbox") $platformstr = 'data-platform="Mapbox"';
  else if ($mapping_service == "ExpressMaps") $platformstr = 'data-platform="MapTiler"';

  if ( $handle == 'storelocatorwidget_locator_js' ) {
    return str_replace( 'src=', 'id="storelocatorscript" data-uid="' . $api . '" ' . $platformstr . ' src=', $tag );
  }
  return $tag;
}


// build the script to replace the short code
function storelocatorwidget_script_output($incomingfromhandler) {
  // avoids Notice: Undefined Index Error
  $headingstart = (isset($incomingfromhandler["headingstart"])) ? $incomingfromhandler["headingstart"] : "";
  $headingend = (isset($incomingfromhandler["headingend"])) ? $incomingfromhandler["headingend"] : "";
  $liststart = (isset($incomingfromhandler["liststart"])) ? $incomingfromhandler["liststart"] : "";
  $listend = (isset($incomingfromhandler["listend"])) ? $incomingfromhandler["listend"] : "";
  $categorylist = (isset($incomingfromhandler["categorylist"])) ? $incomingfromhandler["categorylist"] : "";
  $itemstart = (isset($incomingfromhandler["itemstart"])) ? $incomingfromhandler["itemstart"] : "";
  $itemend = (isset($incomingfromhandler["itemend"])) ? $incomingfromhandler["itemend"] : "";

  $demolp_output = wp_specialchars_decode($headingstart);
  $demolp_output .= wp_specialchars_decode($liststart);

  for ($demolp_count = 1; $demolp_count <= $categorylist; $demolp_count++) {
    $demolp_output .= wp_specialchars_decode($itemstart);
    $demolp_output .= $demolp_count;
    $demolp_output .= " of ";
    $demolp_output .= esc_html($categorylist);
    $demolp_output .= wp_specialchars_decode($itemend);
  }

  $demolp_output .= wp_specialchars_decode($listend);
  $demolp_output .= wp_specialchars_decode($headingend);

  return $demolp_output;
}

// Create the admin menu
function storelocatorwidget_create_menu() {
  //create new top-level menu
  add_menu_page('StoreLocatorWidget Settings', 'Store Locator', 'administrator', 'storelocatorwidgets_slug', 'storelocatorwidget_settings_page',plugins_url('/images/icon.png', __FILE__));
}

// Require the important files
require("functions.php");
require("admin_page.php");
